@@ -34,6 +34,9 @@ objects (called I<loggers>) from its stored namespace.  Most logging
 is then done through a logger object that is specific to the
 application.
 
+For a simple functional interface to the logging sub-system, see
+L<Log::Fine::Utils|Log::Fine::Utils>.
+
 =head2 Handles
 
 Handlers provides a means to output log messages in one or more
@@ -77,7 +80,7 @@ use Log::Fine::Logger;
 use Storable qw( dclone );
 use Sys::Syslog qw( :macros );
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 our @ISA     = qw( Exporter );
 
 =head2 Log Levels
@@ -380,7 +383,7 @@ The Python logging package
 =head1 SEE ALSO
 
 L<perl>, L<syslog>, L<Log::Fine::Handle>, L<Log::Fine::Formatter>,
-L<Log::Fine::Logger>, L<Sys::Syslog>,
+L<Log::Fine::Logger>, L<Log::Fine::Utils>, L<Sys::Syslog>
 
 =head1 AUTHOR
 
@@ -424,7 +427,7 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: Fine.pm 94 2008-07-05 17:54:27Z cfuhrman $
+  $Id: Fine.pm 111 2008-12-09 17:26:43Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
